# 📊 WebEngage Excel Breaker

A lightweight CLI utility to **streamingly extract all sheets from Excel (`.xlsx`) or copy `.csv` files** into individual `.csv` files per sheet, without consuming much memory.

Ideal for handling **large Excel files** that can crash typical pandas-based tools.

---

## 🚀 Features

- ✅ Stream large `.xlsx` files (no RAM overload)
- ✅ Export each sheet to a separate `.csv` file
- ✅ Works with `.csv` files too (makes a copy)
- ✅ CLI-friendly and fast
- ✅ Cross-platform (macOS, Linux, Windows)

---

## Installation


To install the package run:

<pre style="font-size: 16px;">
pip install webengage-excel-breaker
</pre>

---

## Usage

To initiate the separation process run the below command:

<pre style="font-size: 16px;">
we excel-break {/path/filename}
</pre>
<br>

## Legal Notice

This tool is an **internal property** of **WebEngage** and is strictly for **webengage internal purpose**. It is owned by **Nipun Patel (Copyright)** and any misuse, unauthorized distribution, or external sharing will lead to **legal consequences**.

---

© WebEngage. All rights reserved.